{% extends "base_template.html" %}

{% block title %}Main page{% endblock %}

{% block content %}

    <h1 class="h2 mb-3">
        <b>Home</b>
    </h1>

    <div class="row">

    </div>

{% endblock %}
